/**
 * $Id: JamonMonitor.java,v 1.5 2008/12/27 20:34:53 oboehm Exp $
 *
 * Copyright (c) 2008 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 25.12.2008 by oliver (ob@oasd.de)
 */
package patterntesting.runtime.monitor;

import java.util.Date;

import patterntesting.runtime.annotation.UnsupportedOperation;

import com.jamonapi.*;

/**
 * This is a thin wrapper for com.jamonapi.Monitor
 * @see com.jamonapi.Monitor
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 25.12.2008
 * @version $Revision: 1.5 $
 */
public class JamonMonitor extends AbstractProfileMonitor {
    
    private final Monitor monitor;

    public JamonMonitor(Monitor monitor) {
        this.monitor = monitor;
    }

    /**
     * @param arg0
     * @return
     * @see com.jamonapi.Monitor#add(double)
     */
    public void add(double arg0) {
        monitor.add(arg0);
    }

    /**
     * 
     * @see com.jamonapi.Monitor#disable()
     */
    public void disable() {
        monitor.disable();
    }

    /**
     * 
     * @see com.jamonapi.Monitor#enable()
     */
    public void enable() {
        monitor.enable();
    }

    /**
     * @param obj
     * @return
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object obj) {
        return monitor.equals(obj);
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getActive()
     */
    public double getActive() {
        return monitor.getActive();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getAvg()
     */
    public double getAvg() {
        return monitor.getAvg();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getAvgActive()
     */
    public double getAvgActive() {
        return monitor.getAvgActive();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getAvgGlobalActive()
     */
    public double getAvgGlobalActive() {
        return monitor.getAvgGlobalActive();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getAvgPrimaryActive()
     */
    public double getAvgPrimaryActive() {
        return monitor.getAvgPrimaryActive();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getFirstAccess()
     */
    public Date getFirstAccess() {
        return monitor.getFirstAccess();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getHits()
     */
    public int getHits() {
        return (int) monitor.getHits();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getJAMonDetailRow()
     */
    public JAMonDetailRow getJAMonDetailRow() {
        return monitor.getJAMonDetailRow();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getLabel()
     */
    public String getLabel() {
        return monitor.getLabel();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getLastAccess()
     */
    public Date getLastAccess() {
        return monitor.getLastAccess();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getLastValue()
     */
    public double getLastValue() {
        return monitor.getLastValue();
    }

    /**
     * @param listenerType
     * @return
     * @see com.jamonapi.Monitor#getListenerType(java.lang.String)
     */
    public ListenerType getListenerType(String listenerType) {
        return monitor.getListenerType(listenerType);
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getMax()
     */
    public double getMax() {
        return monitor.getMax();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getMaxActive()
     */
    public double getMaxActive() {
        return monitor.getMaxActive();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getMin()
     */
    public double getMin() {
        return monitor.getMin();
    }

    /**
     * @return
     * @see com.jamonapi.MonitorComposite#getMonitors()
     */
    @UnsupportedOperation
    public ProfileMonitor[] getMonitors() {
        return null;
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getMonKey()
     */
    public MonKey getMonKey() {
        return monitor.getMonKey();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getRange()
     */
    public Range getRange() {
        return monitor.getRange();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getStdDev()
     */
    public double getStdDev() {
        return monitor.getStdDev();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getTotal()
     */
    public double getTotal() {
        return monitor.getTotal();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#getUnits()
     */
    public String getUnits() {
        return monitor.getUnits();
    }

    /**
     * @return
     * @see java.lang.Object#hashCode()
     */
    public int hashCode() {
        return monitor.hashCode();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#hasListeners()
     */
    public boolean hasListeners() {
        return monitor.hasListeners();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#isActivityTracking()
     */
    public boolean isActivityTracking() {
        return monitor.isActivityTracking();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#isEnabled()
     */
    public boolean isEnabled() {
        return monitor.isEnabled();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#isPrimary()
     */
    public boolean isPrimary() {
        return monitor.isPrimary();
    }

    /**
     * 
     * @see com.jamonapi.Monitor#reset()
     */
    public void reset() {
        monitor.reset();
    }

    /**
     * @param now
     * @see com.jamonapi.Monitor#setAccessStats(long)
     */
    public void setAccessStats(long now) {
        monitor.setAccessStats(now);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setActive(double)
     */
    public void setActive(double arg0) {
        monitor.setActive(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setActivityTracking(boolean)
     */
    public void setActivityTracking(boolean arg0) {
        monitor.setActivityTracking(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setFirstAccess(java.util.Date)
     */
    public void setFirstAccess(Date arg0) {
        monitor.setFirstAccess(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setHits(double)
     */
    public void setHits(double arg0) {
        monitor.setHits(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setLastAccess(java.util.Date)
     */
    public void setLastAccess(Date arg0) {
        monitor.setLastAccess(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setLastValue(double)
     */
    public void setLastValue(double arg0) {
        monitor.setLastValue(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setMax(double)
     */
    public void setMax(double arg0) {
        monitor.setMax(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setMaxActive(double)
     */
    public void setMaxActive(double arg0) {
        monitor.setMaxActive(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setMin(double)
     */
    public void setMin(double arg0) {
        monitor.setMin(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setPrimary(boolean)
     */
    public void setPrimary(boolean arg0) {
        monitor.setPrimary(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setTotal(double)
     */
    public void setTotal(double arg0) {
        monitor.setTotal(arg0);
    }

    /**
     * @param arg0
     * @see com.jamonapi.Monitor#setTotalActive(double)
     */
    public void setTotalActive(double arg0) {
        monitor.setTotalActive(arg0);
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#start()
     */
    public void start() {
        monitor.start();
    }

    /**
     * @return
     * @see com.jamonapi.Monitor#stop()
     */
    public void stop() {
        monitor.stop();
    }

    /**
     * @return e.g. "JAMon Label=void patterntesting.runtime.monitor.ProfileTest.testProfiler(), Units=ms.:"
     *  + " (LastValue=8.0, Hits=1.0, Avg=8.0, Total=8.0, Min=8.0, Max=8.0, Active=1.0, Avg Active=3.0,"
     *  + " Max Active=2.0, First Access=Sat Dec 27 17:31:09 CET 2008, Last Access=Sat Dec 27 17:31:09 CET 2008)"
     * @see com.jamonapi.Monitor#toString()
     */
    public String toString() {
        return monitor.toString();
    }
    
    public String toShortString() {
        return "Hits=" + (long) monitor.getHits() + ", Avg=" + monitor.getAvg()
            + ", Total=" + monitor.getTotal() + ", Max=" + monitor.getMax()
            + ", Unit=" + monitor.getUnits();
    }
    
    public String toCsvHeadline() {
        return "Label; Unit; LastValue; Hits; Avg; Total; Min; Max; Active; Avg Active; Max Active; First Access; Last Access;";
    }
    
    public String toCsvString() {
        return monitor.getLabel() + "; " + monitor.getUnits() + "; "
                + monitor.getLastValue() + "; " + (long) monitor.getHits()
                + "; " + monitor.getAvg() + "; " + monitor.getTotal() + "; "
                + monitor.getMin() + "; " + monitor.getMax() + "; "
                + monitor.getActive() + "; " + monitor.getAvgActive() + "; "
                + monitor.getMaxActive() + "; " + monitor.getFirstAccess()
                + "; " + monitor.getLastAccess() + ";";
    }

}

/**
 * $Log: JamonMonitor.java,v $
 * Revision 1.5  2008/12/27 20:34:53  oboehm
 * statistic is now sorted after total time (in descending order)
 *
 * Revision 1.4  2008/12/27 20:03:41  oboehm
 * Unit in dumped statistic is now a single column
 *
 * Revision 1.3  2008/12/27 19:45:38  oboehm
 * dumpStatistic() implemented
 *
 * Revision 1.2  2008/12/27 16:58:59  oboehm
 * toShortString() added for more compact statistic
 *
 * Revision 1.1  2008/12/27 13:36:30  oboehm
 * using JAMon for profiling (if found in classpath)
 *
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/monitor/JamonMonitor.java,v $
 */
