/**
 * $Id: ReflectionHelper.java,v 1.2 2009/04/13 13:32:48 oboehm Exp $
 *
 * Copyright (c) 2009 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 09.03.2009 by oliver (ob@aosd.de)
 */
package patterntesting.runtime.util;

import java.lang.reflect.Field;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.impl.LogFactoryImpl;

/**
 * This class is a helper class to access some fields via reflection. Normally
 * you should avoid reflection. Handle with care if you use it.
 * 
 * @author <a href="boehm@javatux.de">oliver</a>
 * @since 09.03.2009
 * @version $Revision: 1.2 $
 */
public class ReflectionHelper {

     private static final Log log = LogFactoryImpl.getLog(ReflectionHelper.class);

    /**
     * Tries to get the wanted field. Before it is returned the acc
     * 
     * @param cl
     * @param name
     * @return the wanted field
     * @throws NoSuchFieldException
     */
    public static Field getField(Class<?> cl, String name)
            throws NoSuchFieldException {
        try {
            Field field = cl.getDeclaredField(name);
            field.setAccessible(true);
            return field;
        } catch (NoSuchFieldException e) {
            Class<?> superclass = cl.getSuperclass();
            if (superclass == null) {
                throw e;
            } else {
                if (log.isTraceEnabled()) {
                    log.trace("using " + superclass + " to get " + cl.getName()
                            + "." + name + "...");
                }
                return ReflectionHelper.getField(superclass, name);
            }
        }
    }

    /**
     * If it can it returns the value of the given field. If not it throws an
     * exception.
     * 
     * @param obj
     * @param name
     * @return
     * @throws NoSuchFieldException
     * @throws IllegalAccessException
     * @throws IllegalArgumentException
     */
    public static Object getFieldValue(Object obj, String name)
            throws NoSuchFieldException, IllegalArgumentException,
            IllegalAccessException {
        Field field = ReflectionHelper.getField(obj.getClass(), name);
        return field.get(obj);
    }

}

/**
 * $Log: ReflectionHelper.java,v $
 * Revision 1.2  2009/04/13 13:32:48  oboehm
 * some small refactorings
 * Revision 1.1 2009/03/09 21:18:54 oboehm
 * refactored out some parts to ReflectionHelper
 * 
 * $Source: /cvsroot/patterntesting/PatternTesting08/patterntesting-rt/src/main/java/patterntesting/runtime/util/ReflectionHelper.java,v $
 */
